==> phpmyadmin-4.5.5.1-1-any.pkg.tar.xz: usr/share/webapps/phpMyAdmin/test/libraries/common/PMA_getDivForSliderEffect_test.php <==
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 ** Test for PMA_Util::getDivForSliderEffect from Util.class.php
 *
 * @package PhpMyAdmin-test
 * @group common.lib-tests
 */

/*
 * Include to test.
 */
require_once 'libraries/Util.class.php';

/**
 ** Test for PMA_Util::getDivForSliderEffect from Util.class.php
 *
 * @package PhpMyAdmin-test
 * @group common.lib-tests
 */
class PMA_GetDivForSliderEffectTest extends PHPUnit_Framework_TestCase
{
    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTest()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'undefined';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA_Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '" class="pma_auto_slider" title="'
            . htmlspecialchars($message) . '">'
        );
    }

    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTestClosed()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'closed';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA_Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '" style="display: none; overflow:auto;" '
            . 'class="pma_auto_slider" title="' . htmlspecialchars($message) . '">'
        );

    }

    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTestDisabled()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'disabled';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA_Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '">'
        );
    }
}

==> phpmyadmin-4.6.4-1-any.pkg.tar.xz: usr/share/webapps/phpMyAdmin/test/libraries/common/PMA_getDivForSliderEffect_test.php <==
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 ** Test for PMA\libraries\Util::getDivForSliderEffect from Util.php
 *
 * @package PhpMyAdmin-test
 * @group common.lib-tests
 */

/*
 * Include to test.
 */


/**
 ** Test for PMA\libraries\Util::getDivForSliderEffect from Util.php
 *
 * @package PhpMyAdmin-test
 * @group common.lib-tests
 */
class PMA_GetDivForSliderEffectTest extends PHPUnit_Framework_TestCase
{
    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTest()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'undefined';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA\libraries\Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '" class="pma_auto_slider" title="'
            . htmlspecialchars($message) . '">'
        );
    }

    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTestClosed()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'closed';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA\libraries\Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '" style="display: none; overflow:auto;" '
            . 'class="pma_auto_slider" title="' . htmlspecialchars($message) . '">'
        );

    }

    /**
     * Test for getDivForSliderEffect
     *
     * @return void
     */
    function testGetDivForSliderEffectTestDisabled()
    {
        global $cfg;
        $cfg['InitialSlidersState'] = 'disabled';

        $id = "test_id";
        $message = "test_message";

        $this->assertEquals(
            PMA\libraries\Util::getDivForSliderEffect($id, $message),
            '<div id="' . $id . '">'
        );
    }
}
